@@ -7,7 +7,7 @@ from ..repository import NumerousRepository
 from ..utils import bold, green, red
 
 
-def command_login(log: Logger, path: Path, admin: bool):
+def command_login(log: Logger, path: Path):
     path = path or Path.cwd()
 
     try:
@@ -28,9 +28,9 @@ def command_login(log: Logger, path: Path, admin: bool):
         print(f"Check out a scenario with {bold('numerous checkout <SCENARIO ID>')}")
         sys.exit(1)
 
-    repo.token = None
     try:
-        login(repo, admin=admin)
+        repo.refresh_token = None
+        login(repo)
         print(green("Login succeeded."))
     except AuthenticationError:
         print(red("Login failed."))
