@@ -55,7 +55,6 @@ def parse_arguments():
 
     parser_login = command_parsers.add_parser("login", help="Login to the repository remote.")
     parser_login.add_argument("path", help="The path to the repository.", nargs="?")
-    parser_login.add_argument("--admin", help="Request the admin level.", action='store_true')
 
     command_parsers.add_parser("version", help="Get the current version number of this tool.")
 
@@ -98,7 +97,7 @@ def run_command(ns: Namespace):
     elif ns.cmd == "version":
         commands.command_version()
     elif ns.cmd == "login":
-        commands.command_login(log, path_or_none(ns.path), ns.admin)
+        commands.command_login(log, path_or_none(ns.path))
     else:
         print(red(f"Invalid {ns.cmd} command given."))
 
