@@ -4,16 +4,16 @@ import tarfile
 from io import BytesIO
 from os import linesep
 from pathlib import Path, PurePosixPath
-from typing import Any, Callable, ContextManager
+from typing import Any, Callable, ContextManager, Optional
 from urllib.parse import urlparse
 from uuid import uuid4
 
 import grpc
 from colorama import Fore, Style, init as init_colorama
 from dirtools import Dir
-from spm_pb2_grpc import BuildManagerStub, SPMStub, TokenManagerStub
+from spm_pb2_grpc import TokenManagerStub
 
-log = logging.getLogger('numerous.build-cli')
+log = logging.getLogger('__name__')
 
 
 init_colorama()
@@ -52,7 +52,7 @@ def print_repository_help_message(path: Path):
     print(f" * Build code and update scenario: {bold(cyan('numerous build'))}")
 
 
-def get_grpc_channel(url: str) -> grpc.Channel:
+def get_grpc_channel(url: str, auth_plugin: Optional[grpc.AuthMetadataPlugin]) -> grpc.Channel:
     parsed_url = urlparse(url)
 
     options = (
@@ -65,7 +65,10 @@ def get_grpc_channel(url: str) -> grpc.Channel:
     if parsed_url.scheme == "https":
         return grpc.secure_channel(
             f"{parsed_url.hostname}:{parsed_url.port or '443'}",
-            grpc.ssl_channel_credentials(),
+            grpc.composite_channel_credentials(
+                grpc.ssl_channel_credentials(),
+                grpc.metadata_call_credentials(auth_plugin)
+            ) if auth_plugin else grpc.ssl_channel_credentials(),
             options=options
         )
     elif parsed_url.hostname == "localhost":
@@ -83,8 +86,9 @@ def get_grpc_channel(url: str) -> grpc.Channel:
 
 
 class StubClient:
-    def __init__(self, api_url: str, stub: Callable[[grpc.Channel], Any]):
-        self.channel = get_grpc_channel(api_url)
+    def __init__(self, api_url: str, stub: Callable[[grpc.Channel], Any],
+                 plugin: Optional[grpc.AuthMetadataPlugin] = None):
+        self.channel = get_grpc_channel(api_url, plugin)
         self.stub = stub(self.channel)
 
     def __enter__(self):
@@ -94,18 +98,10 @@ class StubClient:
         self.channel.close()
 
 
-def get_build_manager(api_url: str) -> ContextManager[BuildManagerStub]:
-    return StubClient(api_url, BuildManagerStub)
-
-
 def get_token_manager(api_url: str) -> ContextManager[TokenManagerStub]:
     return StubClient(api_url, TokenManagerStub)
 
 
-def get_spm(api_url: str) -> ContextManager[SPMStub]:
-    return StubClient(api_url, SPMStub)
-
-
 class GzippedTarball:
 
     def __init__(self, source: Path):
